Learn R Programming

thregI (version 1.0.4)

thregIcure: fit threshold regression cure-rate model for interval-censored data

Description

Fit a threshold regression cure-rate model for interval-censored data and calculate the prediction of the initial health status value, the drift value of the health process and cure rate. Whether the accommodated cure rate exists by goodness-of-fit test compared with the 'thregI'.

Usage

thregIcure(formula, data)

Arguments

formula

a formula object, which has the similar format to that in the thregI(). There are two | operators, on the left-hand side | operator is used for the linear regression function of \(ln{y_0}\) and specifing explaination variables of \(\mu\). On the right of right-hand side | operator is used for specifing explaination variables of \(logit (p)\). A constant \(ln{y_0}\), \(\mu\) or \(logit (p)\) is allowed.

data

a data frame has the same format as that in the thregI().

Examples

Run this code
# NOT RUN {
#load the data "hdsd"
data("hdsd", package="thregI")

#transform the Noadyn variable into factor variable f.noadyn
hdsd$f.noadyn=factor(hdsd$Noadyn)

#fit the threshold regression cure-rate model
#the covariates are TR360, Noadyn, Sex and Age
fit<-thregIcure(Surv(left, right, type='interval2')~f.noadyn+TR360|f.noadyn+TR360|f.noadyn+TR360+
     Sex+Age, data=hdsd)
fit
#note that p-value of the goodness of fit test return by thregIcure function
# }

Run the code above in your browser using DataLab